@@ -11,16 +11,19 @@ class Module:
     def __init__(self, name):
         self.name = name
         os.environ["MODULEPATH"] = os.path.join(config.ali_prefix, 'sw/MODULES', config.architecture)
-        if not runSubprocess(['module', '--version', '--no-pager'], forceTty=True, shell=True):
-            logging.critical('modules not found, exiting...')
-            sys.exit(1)
 
-    def versions(self):
+    def versions(self, filter = True):
         """ List of available versions of given package """
-        avail = runSubprocess(['module', '-t', 'avail', self.name, '--no-pager'], forceTty=True, shell=True).strip()
+        avail = runSubprocess(['module', '-t', 'avail', self.name, '--no-pager'], forceTty=True, shell=True)
+        if not isinstance(avail, str):
+            return []
         versions = []
-        for entry in (avail.split()[1:]):
-            versions.append(entry.rsplit('/')[1])
+        for entry in (avail.strip().split()[1:]):
+            split = entry.rsplit('/')
+            # modules wrongly match prefix, eg. Python matches Python-modules, etc..
+            if split[0] != self.name and filter:
+                continue
+            versions.append(split[1])
         return versions
 
     def deps(self, version):
